"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createPageBlockGraphQL = void 0;
var _GraphQLSchemaPlugin = require("@webiny/handler-graphql/plugins/GraphQLSchemaPlugin");
var _gzip = require("@webiny/utils/compression/gzip");
var _resolve = _interopRequireDefault(require("./utils/resolve"));
const createPageBlockGraphQL = exports.createPageBlockGraphQL = new _GraphQLSchemaPlugin.GraphQLSchemaPlugin({
  typeDefs: /* GraphQL */`
        type PbPageBlock {
            id: ID
            createdOn: DateTime
            createdBy: PbCreatedBy
            name: String
            blockCategory: String
            content: JSON
        }

        input PbCreatePageBlockInput {
            name: String!
            blockCategory: String!
            content: JSON!
        }

        input PbUpdatePageBlockInput {
            name: String
            blockCategory: String
            content: JSON
        }

        input PbListPageBlocksWhereInput {
            blockCategory: String
        }

        # Response types
        type PbPageBlockResponse {
            data: PbPageBlock
            error: PbError
        }

        type PbPageBlockListResponse {
            data: [PbPageBlock]
            error: PbError
        }

        extend type PbQuery {
            listPageBlocks(where: PbListPageBlocksWhereInput): PbPageBlockListResponse
            getPageBlock(id: ID!): PbPageBlockResponse
        }

        extend type PbMutation {
            createPageBlock(data: PbCreatePageBlockInput!): PbPageBlockResponse
            updatePageBlock(id: ID!, data: PbUpdatePageBlockInput!): PbPageBlockResponse
            deletePageBlock(id: ID!): PbDeleteResponse
        }
    `,
  resolvers: {
    PbQuery: {
      getPageBlock: async (_, args, context) => {
        return (0, _resolve.default)(() => {
          return context.pageBuilder.getPageBlock(args.id);
        });
      },
      listPageBlocks: async (_, args, context) => {
        return (0, _resolve.default)(() => {
          return context.benchmark.measure("pageBuilder.listPageBlocks", () => {
            return context.pageBuilder.listPageBlocks(args);
          });
        });
      }
    },
    PbMutation: {
      createPageBlock: async (_, args, context) => {
        return (0, _resolve.default)(() => {
          return context.pageBuilder.createPageBlock(args.data);
        });
      },
      updatePageBlock: async (_, args, context) => {
        return (0, _resolve.default)(() => {
          return context.pageBuilder.updatePageBlock(args.id, args.data);
        });
      },
      deletePageBlock: async (_, args, context) => {
        return (0, _resolve.default)(() => {
          return context.pageBuilder.deletePageBlock(args.id);
        });
      }
    },
    PbPageBlock: {
      content: async block => {
        const value = await (0, _gzip.compress)(JSON.stringify(block.content));
        return {
          compression: "gzip",
          value: value.toString("base64")
        };
      }
    }
  }
});

//# sourceMappingURL=pageBlocks.gql.js.map